@@ -21,4 +21,28 @@ sub shorten_delete_data {
 
 1;
 
-__END__ 
+__END__
+
+=head1 NAME
+
+Catalyst::Plugin::Shorten::Store::Dummy
+
+=head1 SUBROUTINES/METHOS
+
+=head2 shorten_get_data
+
+=cut
+
+=head2 shorten_set_data
+
+=cut
+
+=head2 shorten_delete_data
+
+=cut
+
+=head1 AUTHOR
+
+LNATION, C<< <thisusedtobeanemail at gmail.com> >>
+
+=cut
